==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/streamanalytics/kotlin/inputs/StreamInputPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.streamanalytics.kotlin.inputs

import com.pulumi.azurenative.streamanalytics.inputs.StreamInputPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The properties that are associated with an input containing stream data.
 * @property compression Describes how input data is compressed
 * @property datasource Describes an input data source that contains stream data. Required on PUT (CreateOrReplace) requests.
 * @property partitionKey partitionKey Describes a key in the input data which is used for partitioning the input data
 * @property serialization Describes how data from an input is serialized or how data is serialized when written to an output. Required on PUT (CreateOrReplace) requests.
 * @property type Indicates whether the input is a source of reference data or stream data. Required on PUT (CreateOrReplace) requests.
 * Expected value is 'Stream'.
 */
public data class StreamInputPropertiesArgs(
    public val compression: Output<CompressionArgs>? = null,
    public val datasource: Output<Any>? = null,
    public val partitionKey: Output<String>? = null,
    public val serialization: Output<Any>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.streamanalytics.inputs.StreamInputPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.streamanalytics.inputs.StreamInputPropertiesArgs =
        com.pulumi.azurenative.streamanalytics.inputs.StreamInputPropertiesArgs.builder()
            .compression(compression?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .datasource(datasource?.applyValue({ args0 -> args0 }))
            .partitionKey(partitionKey?.applyValue({ args0 -> args0 }))
            .serialization(serialization?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StreamInputPropertiesArgs].
 */
@PulumiTagMarker
public class StreamInputPropertiesArgsBuilder internal constructor() {
    private var compression: Output<CompressionArgs>? = null

    private var datasource: Output<Any>? = null

    private var partitionKey: Output<String>? = null

    private var serialization: Output<Any>? = null

    private var type: Output<String>? = null

    /**
     * @param value Describes how input data is compressed
     */
    @JvmName("pmqklmvehpsmdvku")
    public suspend fun compression(`value`: Output<CompressionArgs>) {
        this.compression = value
    }

    /**
     * @param value Describes an input data source that contains stream data. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("pxjciercfmcygeki")
    public suspend fun datasource(`value`: Output<Any>) {
        this.datasource = value
    }

    /**
     * @param value partitionKey Describes a key in the input data which is used for partitioning the input data
     */
    @JvmName("hvyjmxywfluhkmui")
    public suspend fun partitionKey(`value`: Output<String>) {
        this.partitionKey = value
    }

    /**
     * @param value Describes how data from an input is serialized or how data is serialized when written to an output. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("hjsllltarhplfwhq")
    public suspend fun serialization(`value`: Output<Any>) {
        this.serialization = value
    }

    /**
     * @param value Indicates whether the input is a source of reference data or stream data. Required on PUT (CreateOrReplace) requests.
     * Expected value is 'Stream'.
     */
    @JvmName("nayjrtcrnvylgsse")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Describes how input data is compressed
     */
    @JvmName("gppdjcclimodyapr")
    public suspend fun compression(`value`: CompressionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.compression = mapped
    }

    /**
     * @param argument Describes how input data is compressed
     */
    @JvmName("yagophpgwlrebtyr")
    public suspend fun compression(argument: suspend CompressionArgsBuilder.() -> Unit) {
        val toBeMapped = CompressionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.compression = mapped
    }

    /**
     * @param value Describes an input data source that contains stream data. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("fmewodlnrmvdyraj")
    public suspend fun datasource(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.datasource = mapped
    }

    /**
     * @param value partitionKey Describes a key in the input data which is used for partitioning the input data
     */
    @JvmName("dxwrctnepfwdvmip")
    public suspend fun partitionKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partitionKey = mapped
    }

    /**
     * @param value Describes how data from an input is serialized or how data is serialized when written to an output. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("gemvhssuahrhyrxm")
    public suspend fun serialization(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serialization = mapped
    }

    /**
     * @param value Indicates whether the input is a source of reference data or stream data. Required on PUT (CreateOrReplace) requests.
     * Expected value is 'Stream'.
     */
    @JvmName("jgepqcqjmqyfuyve")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): StreamInputPropertiesArgs = StreamInputPropertiesArgs(
        compression = compression,
        datasource = datasource,
        partitionKey = partitionKey,
        serialization = serialization,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/streamanalytics/kotlin/inputs/StreamInputPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.streamanalytics.kotlin.inputs

import com.pulumi.azurenative.streamanalytics.inputs.StreamInputPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The properties that are associated with an input containing stream data.
 * @property compression Describes how input data is compressed
 * @property datasource Describes an input data source that contains stream data. Required on PUT (CreateOrReplace) requests.
 * @property partitionKey partitionKey Describes a key in the input data which is used for partitioning the input data
 * @property serialization Describes how data from an input is serialized or how data is serialized when written to an output. Required on PUT (CreateOrReplace) requests.
 * @property type Indicates whether the input is a source of reference data or stream data. Required on PUT (CreateOrReplace) requests.
 * Expected value is 'Stream'.
 */
public data class StreamInputPropertiesArgs(
    public val compression: Output<CompressionArgs>? = null,
    public val datasource: Output<Any>? = null,
    public val partitionKey: Output<String>? = null,
    public val serialization: Output<Any>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.streamanalytics.inputs.StreamInputPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.streamanalytics.inputs.StreamInputPropertiesArgs =
        com.pulumi.azurenative.streamanalytics.inputs.StreamInputPropertiesArgs.builder()
            .compression(compression?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .datasource(datasource?.applyValue({ args0 -> args0 }))
            .partitionKey(partitionKey?.applyValue({ args0 -> args0 }))
            .serialization(serialization?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StreamInputPropertiesArgs].
 */
@PulumiTagMarker
public class StreamInputPropertiesArgsBuilder internal constructor() {
    private var compression: Output<CompressionArgs>? = null

    private var datasource: Output<Any>? = null

    private var partitionKey: Output<String>? = null

    private var serialization: Output<Any>? = null

    private var type: Output<String>? = null

    /**
     * @param value Describes how input data is compressed
     */
    @JvmName("riofnrggncjbgpiu")
    public suspend fun compression(`value`: Output<CompressionArgs>) {
        this.compression = value
    }

    /**
     * @param value Describes an input data source that contains stream data. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("klomnqpecuvadpyh")
    public suspend fun datasource(`value`: Output<Any>) {
        this.datasource = value
    }

    /**
     * @param value partitionKey Describes a key in the input data which is used for partitioning the input data
     */
    @JvmName("ekjuwxbvxjghhusf")
    public suspend fun partitionKey(`value`: Output<String>) {
        this.partitionKey = value
    }

    /**
     * @param value Describes how data from an input is serialized or how data is serialized when written to an output. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("gowepinjdsufriqg")
    public suspend fun serialization(`value`: Output<Any>) {
        this.serialization = value
    }

    /**
     * @param value Indicates whether the input is a source of reference data or stream data. Required on PUT (CreateOrReplace) requests.
     * Expected value is 'Stream'.
     */
    @JvmName("qgyitulynxeielnq")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Describes how input data is compressed
     */
    @JvmName("djsomeeudcwbeual")
    public suspend fun compression(`value`: CompressionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.compression = mapped
    }

    /**
     * @param argument Describes how input data is compressed
     */
    @JvmName("sksrwbntvywsddgt")
    public suspend fun compression(argument: suspend CompressionArgsBuilder.() -> Unit) {
        val toBeMapped = CompressionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.compression = mapped
    }

    /**
     * @param value Describes an input data source that contains stream data. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("bdmkytnbgoxawkkk")
    public suspend fun datasource(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.datasource = mapped
    }

    /**
     * @param value partitionKey Describes a key in the input data which is used for partitioning the input data
     */
    @JvmName("dtunqhbjhovfrwyb")
    public suspend fun partitionKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partitionKey = mapped
    }

    /**
     * @param value Describes how data from an input is serialized or how data is serialized when written to an output. Required on PUT (CreateOrReplace) requests.
     */
    @JvmName("wjwfajfhxapibymp")
    public suspend fun serialization(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serialization = mapped
    }

    /**
     * @param value Indicates whether the input is a source of reference data or stream data. Required on PUT (CreateOrReplace) requests.
     * Expected value is 'Stream'.
     */
    @JvmName("gldbcfmohxduywtd")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): StreamInputPropertiesArgs = StreamInputPropertiesArgs(
        compression = compression,
        datasource = datasource,
        partitionKey = partitionKey,
        serialization = serialization,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
